+++
title = "Multiple videos"
tags = ["front-matter", "videos", "multiple"]
videos = ["video foo.mp4", "bar.mpeg"]
draft = false
+++

If a video path has spaces in it, wrap the whole path in double
quotes.
